#!/bin/bash

# 2.7.1) Crear Usuarios:
function crear_usuarios() {
    PARAM="${1}"
    CONT="${2}"
    NOMBRE="$(jq -r ".${PARAM}[${CONT}].nombre" "${FICHCONFJSON}")"
    vx-funcs-users vx-check_exit_users "${NOMBRE}" && \
    {
        echo "=> El usuario ya existe: ${NOMBRE}" ;
        return 0 ;
    }
    COMENTARIO="$(jq -r ".${PARAM}[${CONT}].comentario" "${FICHCONFJSON}")"
    SHELL="$(jq -r ".${PARAM}[${CONT}].shell" "${FICHCONFJSON}")"
    HOMEUSU="$(jq -r ".${PARAM}[${CONT}].home" "${FICHCONFJSON}")"
    # Creamos el comando base de creación del usuario:
    COMANDO='useradd -c "${COMENTARIO}" -s "${SHELL}" -m -d "${HOMEUSU}" '
    # Añadimos los grupos primario y secundarios de pertenencia:
    GPRIMARIO="$(jq -r ".${PARAM}[${CONT}].grupo_primario" "${FICHCONFJSON}")"
    if [[ "${GPRIMARIO}" != "null" ]] && \
    vx-funcs-users vx-check_exit_groups "${GPRIMARIO}" ; then
        COMANDO+='-g "${GPRIMARIO}" '
    fi
    # En los grupos secundarios tendremos en cuenta: dialout y vboxusers:
    LISTA_GRUPOS=()
    GSECUNDARIOS="$(jq -r ".${PARAM}[${CONT}].grupos_segundarios" "${FICHCONFJSON}")"
    for GRUPO in "dialout" "vboxusers" ${GSECUNDARIOS//,/ } ; do
        vx-funcs-users vx-check_exit_groups "${GRUPO}" && \
        LISTA_GRUPOS+=("${GRUPO}")
    done
    (( ${#LISTA_GRUPOS[@]} > 0 )) && \
    COMANDO+='-G "$(echo "${LISTA_GRUPOS[*]}" | tr -s " " ",")" '
    # Añadimos la contraseña:
    PASS="$(jq -r ".${PARAM}[${CONT}].password" "${FICHCONFJSON}")"
    PASSPLAIN="$(jq -r ".${PARAM}[${CONT}].password_plain" "${FICHCONFJSON}")"
    if [[ "${PASS}" != "null" ]] ; then
        "${PASSPLAIN}" && \
        COMANDO+='-p "$(mkpasswd -s -m sha-512 "${PASS}")" ' || \
        COMANDO+='-p "${PASS}" '
    fi
    # Por último añadimo el nombre del usuario a crear:
    COMANDO+='${NOMBRE}'
    if eval ${COMANDO} ; then
        "${echo_verde}" "=> Se ha creado la cuenta de usuario: ${NOMBRE}"
    else
        "${echo_rojo}" "=> Problemas para crear la cuenta de usuario: ${NOMBRE}"
    fi
    # Configuramos el idioma del usuario si fuera necesario:
    IDIOMA="$(jq -r ".${PARAM}[${CONT}].idioma" "${FICHCONFJSON}")"
    if [[ "${IDIOMA}" != "null" ]] ; then
        # p.e. IDIOMA="en:en_GB.UTF-8;fr_FR:fr_FR.UTF-8:es_ES:es_ES.UTF-8"
        # Eliminamos el sufijo a partir del ":":
        LENGUAJE="${IDIOMA%:*}"
        # Eliminamos el prefijo hasta el ":":
        FORMATOLOCAL="${IDIOMA#*:}"
        if vx-funcs-users vx-conf_idioma_usuario "${NOMBRE}" "${LENGUAJE}" "${FORMATOLOCAL}" ; then
            "${echo_verde}" "=> ¡¡Ok!! Se han configurado el idioma: ${NOMBRE} ${IDIOMA}"
        else
            "${echo_rojo}" "=> ¡¡Error!! Problemas para para configurar el idioma: ${NOMBRE} ${IDIOMA}"
        fi
    fi
}

"${echo_titulo}" "*  [[ Creación de Usuarios ... ]]  *"
PARAM="usuarios.crear.lista"
# check_parametro [parametro] [breve descripción] [función a llamar]
check_parametro "${PARAM}" "Crear Usuarios" "crear_usuarios"

# 2.7.2) Eliminar usuarios del sistema:
function eliminar_usuarios() {
    PARAM="${1}"
    CONT="${2}"
    # Rescatamos los parametros del comando a ejecutar /usr/bin/vx-conf-lanzadores-desktop:
    USUARIOS="$(jq -r ".${PARAM}[${CONT}].usuarios" "${FICHCONFJSON}" | tr -s ";" " ")"
    for USUARIO in ${USUARIOS} ; do
        USUARIO="$(vx-check-usu-igualdad "${USUARIO}")"
        if vx-funcs-users vx-borrar_usuario "${USUARIO}" ; then
            "${echo_verde}" "=> ¡¡Ok!! Se han eliminado el usuario: ${USUARIO}"
        else
            "${echo_rojo}" "=> ¡¡Error!! Problemas para eliminar el usuario: ${USUARIO}"
        fi
    done
}

"${echo_titulo}" "*  [[ Eliminar Cuentas de Usuario de Vitalinux ... ]]  *"
PARAM="usuarios.eliminar.lista"
# check_parametro [parametro] [breve descripción] [función a llamar]
check_parametro "${PARAM}" "Eliminar Cuentas de Usuario" "eliminar_usuarios"

# 2.7.3) Modificación de las passwords por defecto de usuarios existentes en el equipo:
function modificar_passwords() {
    PARAM="${1}"
    CONT="${2}"
    TOTALUSUS="$(jq -r ".${PARAM}[${CONT}].passusus | length" "${FICHCONFJSON}")"
    CONT2=0
    while (( ${CONT2} < ${TOTALUSUS} )) ;  do
        USUARIO="$(jq -r ".${PARAM}[${CONT}].passusus[${CONT2}].usuario" "${FICHCONFJSON}")"
        USUARIO="$(vx-check-usu-igualdad "${USUARIO}")"
        PASSWORD="$(jq -r ".${PARAM}[${CONT}].passusus[${CONT2}].password" "${FICHCONFJSON}")"
        "${echo_verde}" "=> Se va a modificar la password: ${USUARIO}:${PASSWORD}"
        if vx-funcs-users vx-modificar_password "${USUARIO}" "${PASSWORD}" ; then
            "${echo_verde}" "=> ¡¡Ok!! Modificación password: ${USUARIO}:${PASSWORD}"
        else
            "${echo_rojo}" "=> ¡¡Error!! Modificación password: ${USUARIO}:${PASSWORD}"
        fi
        (( CONT2++ ))
    done
}

"${echo_titulo}" "*  [[ Modficicación Passwords Usuarios ... ]]  *"
PARAM="usuarios.passwords"
# check_parametro [parametro] [breve descripción] [función a llamar]
check_parametro "${PARAM}" "Modificacion Passwords" "modificar_passwords"

# 2.7.4) Modificar usuarios:
function modificar_usuario() {
    PARAM="${1}"
    CONT="${2}"
    NOMBRE="$(jq -r ".${PARAM}[${CONT}].usuario" "${FICHCONFJSON}")"
    NOMBRE="$(vx-check-usu-igualdad "${NOMBRE}")"
    # Comprobamos que el usuario existe:
    vx-funcs-users vx-check_exit_users "${NOMBRE}" && \
    {
        "${echo_verde}" "=> Va a modificarse la cuenta de usuario: ${NOMBRE}" ;
    } || \
    {
        "${echo_rojo}" "=> Error ... no va a modificarse la cuenta de usuario, no existe: ${NOMBRE}" ;
        return ;
    }
    # Creamos el comando base de modificación del usuario:
    COMANDO='usermod "${NOMBRE}" '
    COMENTARIO="$(jq -r ".${PARAM}[${CONT}].comentario" "${FICHCONFJSON}")"
    [[ "${COMENTARIO}" != "null" ]] && COMANDO+='-c "${COMENTARIO}" '
    SHELL="$(jq -r ".${PARAM}[${CONT}].shell" "${FICHCONFJSON}")"
    [[ "${SHELL}" != "null" ]] && COMANDO+='-s "${SHELL}" '
    HOMEUSU="$(jq -r ".${PARAM}[${CONT}].home" "${FICHCONFJSON}")"
    if [[ "${HOMEUSU}" != "null" ]] ; then
        [[ -d "${HOMEUSU}" ]] && COMANDO+='-d "${HOMEUSU}" ' || COMANDO+='-m -d "${HOMEUSU}" '
    fi
    # Añadimos los grupos primario y secundarios de pertenencia:
    GPRIMARIO="$(jq -r ".${PARAM}[${CONT}].grupo_primario" "${FICHCONFJSON}")"
    if [[ "${GPRIMARIO}" != "null" ]] && \
    vx-funcs-users vx-check_exit_groups "${GPRIMARIO}" ; then
        COMANDO+='-g "${GPRIMARIO}" '
    fi
    # En los grupos secundarios tendremos en cuenta: dialout y vboxusers:
    LISTA_GRUPOS=()
    GSECUNDARIOS="$(jq -r ".${PARAM}[${CONT}].grupos_segundarios" "${FICHCONFJSON}")"
    ADDGSECUNDARIOS="$(jq -r ".${PARAM}[${CONT}].add_grupos_secundarios" "${FICHCONFJSON}")"
    "${ADDGSECUNDARIOS}" && OPCIONGS="-aG" || OPCIONGS="-G"
    for GRUPO in "dialout" "vboxusers" ${GSECUNDARIOS//,/ } ; do
        vx-funcs-users vx-check_exit_groups "${GRUPO}" && \
        LISTA_GRUPOS+=("${GRUPO}")
    done
    (( ${#LISTA_GRUPOS[@]} > 0 )) && \
    COMANDO+='${OPCIONGS} "$(echo "${LISTA_GRUPOS[*]}" | tr -s " " ",")" '
    if eval ${COMANDO} 2> /dev/null ; then
        "${echo_verde}" "=> Se ha modificado la cuenta de usuario: ${NOMBRE}"
    else
        "${echo_rojo}" "=> Problemas para modificar la cuenta de usuario: ${NOMBRE}"
    fi
}

"${echo_titulo}" "*  [[ Modficicar Usuarios ... ]]  *"
PARAM="usuarios.modificar.lista"
# check_parametro [parametro] [breve descripción] [función a llamar]
check_parametro "${PARAM}" "Modificar Usuarios" "modificar_usuario"